@@ -132,7 +132,7 @@ func (si *scrollPositionInternal) handleNegativeDeltaScreenLines(pager *Pager) {
 		previousLine := pager.Reader().GetLine(previousLineIndex)
 		previousSubLinesCount := 0
 		if previousLine != nil {
-			previousSubLines := pager.renderLine(previousLine, si.getMaxNumberPrefixLength(pager), true)
+			previousSubLines := pager.renderLine(*previousLine, si.getMaxNumberPrefixLength(pager), true)
 			previousSubLinesCount = len(previousSubLines)
 		}
 
@@ -166,14 +166,14 @@ func (si *scrollPositionInternal) handlePositiveDeltaScreenLines(pager *Pager) {
 			if line == nil {
 				panic(fmt.Errorf("Last line is nil"))
 			}
-			subLines := pager.renderLine(line, maxPrefixLength, true)
+			subLines := pager.renderLine(*line, maxPrefixLength, true)
 
 			// ... and go to the bottom of that.
 			si.deltaScreenLines = len(subLines) - 1
 			return
 		}
 
-		subLines := pager.renderLine(line, maxPrefixLength, true)
+		subLines := pager.renderLine(*line, maxPrefixLength, true)
 		if si.deltaScreenLines < len(subLines) {
 			// Sublines are within bounds!
 			return
@@ -212,7 +212,7 @@ func (si *scrollPositionInternal) emptyBottomLinesCount(pager *Pager) int {
 			break
 		}
 
-		subLines := pager.renderLine(line, lastLineNumberWidth, true)
+		subLines := pager.renderLine(*line, lastLineNumberWidth, true)
 		unclaimedViewportLines -= len(subLines)
 		if unclaimedViewportLines <= 0 {
 			return 0
@@ -323,7 +323,7 @@ func (p *Pager) scrollToEnd() {
 
 	// Scroll down enough. We know for sure the last line won't wrap into more
 	// lines than the number of characters it contains.
-	p.scrollPosition.internalDontTouch.deltaScreenLines = len(lastInputLine.Line.Plain(&lastInputLine.Index))
+	p.scrollPosition.internalDontTouch.deltaScreenLines = len(lastInputLine.Line.Plain(lastInputIndex))
 
 	if p.TargetLine == nil {
 		// Start following the end of the file
@@ -346,6 +346,15 @@ func (p *Pager) isScrolledToEnd() bool {
 	lastInputLineIndex := *linemetadata.IndexFromLength(inputLineCount)
 
 	visibleLines := p.renderLines().lines
+	if len(visibleLines) == 0 {
+		// This can happen when terminal height is 1. In that case, the status
+		// bar takes up that single line, leaving no room for contents.
+		//
+		// The actual return value here was picked based on that it prevents the
+		// crash reported here: https://github.com/walles/moor/issues/378
+		return true
+	}
+
 	lastVisibleLine := visibleLines[len(visibleLines)-1]
 	if lastVisibleLine.inputLineIndex != lastInputLineIndex {
 		// Last input line is not on the screen
@@ -355,7 +364,7 @@ func (p *Pager) isScrolledToEnd() bool {
 	// Last line is on screen, now we need to figure out whether we can see all
 	// of it
 	lastInputLine := p.Reader().GetLine(lastInputLineIndex)
-	lastInputLineRendered := p.renderLine(lastInputLine, p.getLineNumberPrefixLength(lastInputLine.Number), true)
+	lastInputLineRendered := p.renderLine(*lastInputLine, p.getLineNumberPrefixLength(lastInputLine.Number), true)
 	lastRenderedSubLine := lastInputLineRendered[len(lastInputLineRendered)-1]
 
 	// If the last visible subline is the same as the last possible subline then
@@ -364,20 +373,14 @@ func (p *Pager) isScrolledToEnd() bool {
 }
 
 // Returns nil if there are no lines
-func (p *Pager) getLastVisiblePosition() *scrollPosition {
+func (p *Pager) getLastVisibleLineIndex() *linemetadata.Index {
 	rendered := p.renderLines()
 	if len(rendered.lines) == 0 {
 		return nil
 	}
 
 	lastRenderedLine := rendered.lines[len(rendered.lines)-1]
-	return &scrollPosition{
-		internalDontTouch: scrollPositionInternal{
-			name:             "Last Visible Position",
-			lineIndex:        &lastRenderedLine.inputLineIndex,
-			deltaScreenLines: lastRenderedLine.wrapIndex,
-		},
-	}
+	return &lastRenderedLine.inputLineIndex
 }
 
 func (si *scrollPositionInternal) getMaxNumberPrefixLength(pager *Pager) int {
